@@ -5,7 +5,7 @@ package MarpaX::Java::ClassFile::Role::Parser;
 
 # ABSTRACT: Parsing engine role for .class file parsing
 
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
@@ -110,19 +110,28 @@ sub _build_ast {
   #
   no warnings 'once';
   local $MarpaX::Java::ClassFile::Role::Parser::SELF = $_[0];
-  local $MarpaX::Java::ClassFile::Role::Parser::G = $_[0]->grammar;
+  local $MarpaX::Java::ClassFile::Role::Parser::G    = $_[0]->grammar;
   #
   # It is far quicker to maintain ourself booleans for trace and debug mode
   # rather than letting logger's tracef() and debugf() handle the request.
   # Further more we do //= because these really should be constant once
-  # a parsing is starting.
+  # parse is starting.
+  # The following can look strange but is my way to makes sure that $[0]->log is called once per parse -;
+  # even when setting localized variables.
   #
-  local $MarpaX::Java::ClassFile::Role::Parser::IS_TRACE //= $_[0]->_logger->is_trace;
-  local $MarpaX::Java::ClassFile::Role::Parser::IS_DEBUG //= $_[0]->_logger->is_debug;
-  local $MarpaX::Java::ClassFile::Role::Parser::IS_INFO  //= $_[0]->_logger->is_info;
-  local $MarpaX::Java::ClassFile::Role::Parser::IS_WARN  //= $_[0]->_logger->is_warn;
-  local $MarpaX::Java::ClassFile::Role::Parser::IS_ERROR //= $_[0]->_logger->is_error;
-  local $MarpaX::Java::ClassFile::Role::Parser::IS_FATAL //= $_[0]->_logger->is_fatal;
+  my $IS_TRACE = $MarpaX::Java::ClassFile::Role::Parser::IS_TRACE;
+  my $IS_DEBUG = $MarpaX::Java::ClassFile::Role::Parser::IS_DEBUG;
+  my $IS_INFO  = $MarpaX::Java::ClassFile::Role::Parser::IS_INFO;
+  my $IS_WARN  = $MarpaX::Java::ClassFile::Role::Parser::IS_WARN;
+  my $IS_ERROR = $MarpaX::Java::ClassFile::Role::Parser::IS_ERROR;
+  my $IS_FATAL = $MarpaX::Java::ClassFile::Role::Parser::IS_FATAL;
+
+  local $MarpaX::Java::ClassFile::Role::Parser::IS_TRACE = $IS_TRACE // $_[0]->log->is_trace;
+  local $MarpaX::Java::ClassFile::Role::Parser::IS_DEBUG = $IS_DEBUG // $_[0]->log->is_debug;
+  local $MarpaX::Java::ClassFile::Role::Parser::IS_INFO  = $IS_INFO  // $_[0]->log->is_info;
+  local $MarpaX::Java::ClassFile::Role::Parser::IS_WARN  = $IS_WARN  // $_[0]->log->is_warn;
+  local $MarpaX::Java::ClassFile::Role::Parser::IS_ERROR = $IS_ERROR // $_[0]->log->is_error;
+  local $MarpaX::Java::ClassFile::Role::Parser::IS_FATAL = $IS_FATAL // $_[0]->log->is_fatal;
   #
   # Localize recognizer
   #
@@ -427,6 +436,7 @@ sub _inner {
                                constant_pool       => $_[0]->constant_pool,
                                inputRef            => $_[0]->inputRef,
                                pos                 => $_[0]->pos,
+                               log                 => $_[0]->log,
                                %args);
   my $innerGrammarValue = $inner->ast;
   $_[0]->lexeme_read('MANAGED', $inner->pos - $_[0]->pos, $innerGrammarValue, $_[2]);
@@ -452,9 +462,9 @@ sub _dolog {
     my $nbcharacters = length("$inputLength");
     my ($offset, $max) = ($self->pos, $self->max);
 
-    $self->_logger->$method("[pos %*s->%*s] %s: $format", $nbcharacters, $offset, $nbcharacters, $self->max, $self->whoami, @arguments)
+    $self->log->$method("[pos %*s->%*s] %s: $format", $nbcharacters, $offset, $nbcharacters, $self->max, $self->whoami, @arguments)
   } else {
-    $self->_logger->$method("%s: $format", $self->whoami, @arguments)
+    $self->log->$method("%s: $format", $self->whoami, @arguments)
   }
 }
 
@@ -511,7 +521,7 @@ sub _croak {
   croak($msg)
 }
 
-with qw/MooX::Role::Logger MarpaX::Java::ClassFile::Role::Parser::Actions/;
+with qw/MooX::Log::Any MarpaX::Java::ClassFile::Role::Parser::Actions/;
 
 requires 'callbacks';
 requires 'grammar';
@@ -591,7 +601,7 @@ MarpaX::Java::ClassFile::Role::Parser - Parsing engine role for .class file pars
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 DESCRIPTION
 
